DEFAULT_LANGUAGE = 'en'

FIRST_TEXT = {
	'en': "Hello!",
	'ru': "Привет!"
}

def get_text(lang_code: str, text: dict[str, str]) -> str:
    if not lang_code in text.keys():
        lang_code = DEFAULT_LANGUAGE
    return text[lang_code]
